@@ -1,8 +1,7 @@
 import typer
 
 import os
-pwd = os.getcwd()
-os.system('export PYTHONPATH="${PYTHONPATH}:'+pwd+'"')
+os.system('export PYTHONPATH=.')
 
 import lib.wifi as wifi
 import lib.bt as bt
